import React, { useRef, useState, useEffect } from 'react';
import 'go-design-system-theme/lib/styles.css';
import ContextMenu from 'go-design-system-context-menu';
import Button from 'go-design-system-button';

const Item = props => {
  const {
    item,
    sanitizedItems,
    index
  } = props;
  const isLast = sanitizedItems.length - 1 === index;
  const ref = useRef();
  const [isMoreContextVisible, setIsMoreContextVisible] = useState(false);
  useEffect(() => {
    function handleClickOutside(event) {
      if (ref.current && !ref.current.contains(event.target)) {
        setIsMoreContextVisible(false);
      }
    }
    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, [ref]);
  const className = item.disabled ? 'disabled' : '';
  return /*#__PURE__*/React.createElement("div", {
    className: `item ${className}`
  }, /*#__PURE__*/React.createElement(Button, {
    title: item.title,
    leftIcon: item.leftIcon,
    variant: isLast ? 'blacktransparent' : 'greytransparent',
    style: item?.style || {}
    // style={{
    //   width: 'fit-content',
    // }}
    ,
    rightIcon: item.rightIcon,
    onClick: e => {
      if (item?.onClick && !item?.disabled) {
        item?.onClick(e);
      }
      if (item.subOptions) {
        setIsMoreContextVisible(true);
      }
    }
  }), sanitizedItems.length > index + 1 ? /*#__PURE__*/React.createElement("div", {
    className: "slash"
  }, "/") : '', item.subOptions && /*#__PURE__*/React.createElement(ContextMenu, {
    yPos: "30px",
    xPos: "140px",
    ref: ref,
    showMenu: isMoreContextVisible,
    items: item.subOptions,
    containerStyles: {
      width: 140
    }
  }));
};
const BreadCrumbs = props => {
  const {
    items,
    containerStyles = {}
  } = props;
  const ref = useRef();
  const [isMoreContextVisible, setIsMoreContextVisible] = useState(false);
  useEffect(() => {
    function handleClickOutside(event) {
      if (ref.current && !ref.current.contains(event.target)) {
        setIsMoreContextVisible(false);
      }
    }
    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, [ref]);
  const sanitizeBreadCrumbsToShow = () => {
    if (items.length < 4) {
      return items;
    } else {
      return [items[0], {
        title: '...',
        onClick: () => {
          setIsMoreContextVisible(!isMoreContextVisible);
        },
        style: {
          width: '2rem'
        }
      }, items[items.length - 1]];
    }
  };
  const getOthersContextMenu = () => {
    if (items.length > 3) {
      const otherItems = [...items];
      otherItems.shift();
      otherItems.pop();
      return otherItems.map(item => {
        return {
          title: item.title,
          disabled: item.disabled,
          icon: item.icon,
          onClick: e => {
            setIsMoreContextVisible(false);
            if (item.onClick) {
              item.onClick(e);
            }
          }
        };
      });
    }
  };
  const sanitizedItems = sanitizeBreadCrumbsToShow();
  const othersContextMenu = getOthersContextMenu();
  return /*#__PURE__*/React.createElement("div", {
    style: containerStyles
  }, /*#__PURE__*/React.createElement("div", {
    className: "go-design-system-bread-crumbs"
  }, sanitizedItems.map((item, i) => {
    return /*#__PURE__*/React.createElement(Item, {
      item: item,
      sanitizedItems: sanitizedItems,
      key: `breadcrumb_${i}`,
      index: i
    });
  }), /*#__PURE__*/React.createElement(ContextMenu, {
    yPos: "30px",
    xPos: "90px",
    ref: ref,
    showMenu: isMoreContextVisible,
    items: othersContextMenu,
    containerStyles: {
      width: 150
    }
  })));
};

export default BreadCrumbs;
